NLSL: mnbrak.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
mnbrak.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | mnbrak (ax, bx, cx, fa, fb, fc, func, iflag, bound)

## Function/Subroutine Documentation

subroutine mnbrak | ( | double precision | ax,
|  | double precision | bx,
|  | double precision | cx,
|  | double precision | fa,
|  | double precision | fb,
|  | double precision | fc,
|  | external | func,
|  | integer | iflag,
|  | double precision | bound
| ) |  |

Definition at line 2 of file mnbrak.f90.

Here is the caller graph for this function: